==> use-async-call-3.1.0.tgz: package/dist-src/index.js <==
import { useEffect, useCallback, useState } from 'react';
import useAsyncReducer from 'use-async-reducer';
function getUpdaterPromise(asyncUpdater) {
    if (typeof asyncUpdater === 'function') {
        return asyncUpdater();
    }
    return asyncUpdater;
}
function useRefreshSymbol() {
    const [refreshSymbol, setRefreshSymbol] = useState(() => Symbol());
    const updateSymbol = useCallback(() => {
        setRefreshSymbol(Symbol());
    }, [setRefreshSymbol]);
    return [refreshSymbol, updateSymbol];
}
/**
 * Provides an abstraction to manage async state
 * @param asyncCreator Async method to call, create this method with `useCallback` if it uses state from the component
 * @param options
 * @returns An array of two values
 *  0. State of the async operation, an object with keys `data`, `loading`, `error`
 *  1. An object of dispatch method to update the state
 *
 * @see [https://github.com/azmenak/use-async-call/blob/master/README.md](https://github.com/azmenak/use-async-call/blob/master/README.md)
 */
export default function useAsyncCall(asyncCreator, options = {}) {
    const [refreshSymbol, refresh] = useRefreshSymbol();
    const [response, actions] = useAsyncReducer(options.initialValue);
    useEffect(() => {
        let didCancel = false;
        const callAsync = async () => {
            actions.request();
            try {
                const data = await asyncCreator();
                if (didCancel) {
                    return;
                }
                actions.success(data);
                if (typeof options.onSuccess === 'function') {
                    options.onSuccess(data);
                }
            }
            catch (error) {
                if (didCancel) {
                    return;
                }
                actions.failure(error);
                if (typeof options.onFailure === 'function') {
                    options.onFailure(error);
                }
            }
            finally {
                if (didCancel) {
                    return;
                }
                if (typeof options.onComplete === 'function') {
                    options.onComplete();
                }
            }
        };
        callAsync();
        return () => {
            didCancel = true;
        };
    }, [asyncCreator, refreshSymbol]);
    const update = useCallback(async (asyncUpdater, updateOptions = {}) => {
        actions.request();
        try {
            const data = await getUpdaterPromise(asyncUpdater);
            actions.success(data);
            if (typeof updateOptions.onSuccess === 'function') {
                updateOptions.onSuccess(data);
            }
            return data;
        }
        catch (error) {
            if (updateOptions.saveError) {
                actions.failure(error);
            }
            else {
                actions.complete();
            }
            if (typeof updateOptions.onFailure === 'function') {
                updateOptions.onFailure(error);
            }
            if (updateOptions.throwError) {
                throw error;
            }
        }
        finally {
            if (typeof updateOptions.onComplete === 'function') {
                updateOptions.onComplete();
            }
        }
    }, [actions]);
    return [response, { update, refresh, actions }];
}

==> use-async-call-3.2.0.tgz: package/dist-src/index.js <==
import { useEffect, useCallback, useState, useRef } from 'react';
import useAsyncReducer from 'use-async-reducer';
function getUpdaterPromise(asyncUpdater) {
    if (typeof asyncUpdater === 'function') {
        return asyncUpdater();
    }
    return asyncUpdater;
}
/**
 * Returns a Symbol which can be used as a dep
 */
export function useRefreshSymbol() {
    const [refreshSymbol, setRefreshSymbol] = useState(() => Symbol());
    const updateSymbol = useCallback(() => {
        setRefreshSymbol(Symbol());
    }, [setRefreshSymbol]);
    return [refreshSymbol, updateSymbol];
}
/**
 * Returns previous value, or null if first render pass
 * @param value updating value
 */
export function usePrevious(value) {
    const ref = useRef(null);
    useEffect(() => {
        ref.current = value;
    }, [value]);
    return ref.current;
}
/**
 * Provides an abstraction to manage async state
 * @param asyncCreator Async method to call, create this method with `useCallback` if it uses state from the component
 * @param options
 * @returns An array of two values
 *  0. State of the async operation, an object with keys `data`, `loading`, `error`
 *  1. An object of dispatch method to update the state
 *
 * @see [https://github.com/azmenak/use-async-call/blob/master/README.md](https://github.com/azmenak/use-async-call/blob/master/README.md)
 */
export default function useAsyncCall(asyncCreator, options = {}) {
    const [refreshSymbol, refresh] = useRefreshSymbol();
    const previousAsyncCreator = usePrevious(asyncCreator);
    const [response, actions] = useAsyncReducer(options.initialValue);
    useEffect(() => {
        let didCancel = false;
        const callAsync = async () => {
            if (asyncCreator === previousAsyncCreator) {
                actions.request();
            }
            else {
                actions.initialize();
            }
            try {
                const data = await asyncCreator();
                if (didCancel) {
                    return;
                }
                actions.success(data);
                if (typeof options.onSuccess === 'function') {
                    options.onSuccess(data);
                }
            }
            catch (error) {
                if (didCancel) {
                    return;
                }
                actions.failure(error);
                if (typeof options.onFailure === 'function') {
                    options.onFailure(error);
                }
            }
            finally {
                if (didCancel) {
                    return;
                }
                if (typeof options.onComplete === 'function') {
                    options.onComplete();
                }
            }
        };
        callAsync();
        return () => {
            didCancel = true;
        };
    }, [asyncCreator, refreshSymbol]);
    const isUnmounted = useRef(false);
    useEffect(() => {
        return () => {
            isUnmounted.current = true;
        };
    }, []);
    const update = useCallback(async (asyncUpdater, updateOptions = {}) => {
        const updateCreatorOwner = asyncCreator;
        actions.request();
        try {
            const data = await getUpdaterPromise(asyncUpdater);
            if (updateCreatorOwner === previousAsyncCreator &&
                !isUnmounted.current) {
                actions.success(data);
            }
            if (typeof updateOptions.onSuccess === 'function') {
                updateOptions.onSuccess(data);
            }
            return data;
        }
        catch (error) {
            if (updateCreatorOwner === previousAsyncCreator &&
                !isUnmounted.current) {
                if (updateOptions.saveError) {
                    actions.failure(error);
                }
                else {
                    actions.complete();
                }
            }
            if (typeof updateOptions.onFailure === 'function') {
                updateOptions.onFailure(error);
            }
            if (updateOptions.throwError) {
                throw error;
            }
        }
        finally {
            if (typeof updateOptions.onComplete === 'function') {
                updateOptions.onComplete();
            }
        }
    }, [actions, asyncCreator]);
    return [response, { update, refresh, actions }];
}
